package
Version:
v0.0.0-...-5513f93
Opens a new window with list of versions in this module.
Published: Apr 30, 2024
License: GPL-3.0
Opens a new window with license information.
Imports: 0
Opens a new window with list of imports.
Imported by: 0
Opens a new window with list of known importers.
Documentation
¶
func Map[E, D any](s []E, f func(e E) D) []D
Source Files
¶
Click to show internal directories.
Click to hide internal directories.